@@ -43,11 +43,6 @@ remote <- function(func, args = list()) {
           )
           invokeRestart("cli_message_handled")
         },
-        error = function(e) {
-          e$formatted_message <- capture.output(print(e))
-          class(e) <- c("pak_error", class(e))
-          stop(e)
-        },
         {
           options(pkg.show_progress = `__verbosity__`, repos = `__repos__`)
           `__body__`
@@ -68,17 +63,12 @@ remote <- function(func, args = list()) {
     },
     rs$run_with_output(func2, args)
   )
+
   if (!is.null(res$error)) {
-    if (inherits(res$error$parent$error, "condition") &&
-        inherits(res$error$parent, "condition")) {
-      err$rethrow(stop(res$error$parent$error), res$error$parent, call = FALSE)
-    } else {
-      print(res$error)
-      print(res$error$parent)
-      print(res$error$parent$error)
-      if (inherits(res$error, "condition")) err$throw(res$error)
-      stop("Unknown error from subprocess")
+    if (inherits(res$error, "callr_status_error")) {
+      res$error$message <- "error in pak subprocess"
     }
+    err$throw(res$error)
   }
 
   res$result
@@ -95,10 +85,12 @@ new_remote_session <- function() {
   cli <- pkg_data$ns$cli
   opts <- callr$r_session_options(stderr = NULL,  stdout = NULL)
   opts$env <- c(
-    opts$env, R_PKG_SHOW_PROGRESS = is_verbose(),
+    opts$env,
+    R_PKG_SHOW_PROGRESS = is_verbose(),
     R_PKG_PKG_WORKER = "true",
     R_PKG_NUM_COLORS = as.character(cli$num_ansi_colors()),
-    R_PKG_DYNAMIC_TTY = cli$is_dynamic_tty()
+    R_PKG_DYNAMIC_TTY = cli$is_dynamic_tty(),
+    PKGCACHE_NO_PILLAR = "true"
   )
   pkg_data$remote <- callr$r_session$new(opts, wait = FALSE)
 }
@@ -212,6 +204,25 @@ load_private_package <- function(package, reg_prefix = "",
     pkg_env$err$.internal$package_env <- pkg_env
   }
 
+  # patch processx and callr
+  if (package %in% c("callr", "processx")) {
+    assign("has_cli", function() TRUE, envir = pkg_env$err$.internal)
+  }
+  if (package == "callr") {
+    registerS3method(
+      "format",
+      "callr_status_error",
+      pkg_env$format.callr_status_error,
+      baseenv()
+    )
+    registerS3method(
+      "print",
+      "callr_status_error",
+      pkg_env$print.callr_status_error,
+      baseenv()
+    )
+  }
+
   # Hack to avoid S3 dispatch
   if (package == "glue") {
     pkg_env$as_glue <- pkg_env$as_glue.character
